@@ -18,7 +18,7 @@
  */
 
 #include <config.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include "pixbuf-document.h"
 #include "ev-document-thumbnails.h"
@@ -27,12 +27,12 @@
 
 struct _PixbufDocumentClass
 {
-	GObjectClass parent_class;
+	EvDocumentClass parent_class;
 };
 
 struct _PixbufDocument
 {
-	GObject parent_instance;
+	EvDocument parent_instance;
 
 	GdkPixbuf *pixbuf;
 	
@@ -41,7 +41,6 @@ struct _PixbufDocument
 
 typedef struct _PixbufDocumentClass PixbufDocumentClass;
 
-static void pixbuf_document_document_iface_init (EvDocumentIface *iface);
 static void pixbuf_document_document_thumbnails_iface_init (EvDocumentThumbnailsIface *iface);
 
 EV_BACKEND_REGISTER_WITH_CODE (PixbufDocument, pixbuf_document,
@@ -142,31 +141,16 @@ pixbuf_document_finalize (GObject *object)
 static void
 pixbuf_document_class_init (PixbufDocumentClass *klass)
 {
-	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+	GObjectClass    *gobject_class = G_OBJECT_CLASS (klass);
+	EvDocumentClass *ev_document_class = EV_DOCUMENT_CLASS (klass);
 
 	gobject_class->finalize = pixbuf_document_finalize;
-}
 
-static EvDocumentInfo *
-pixbuf_document_get_info (EvDocument *document)
-{
-	EvDocumentInfo *info;
-
-	info = g_new0 (EvDocumentInfo, 1);
-	info->fields_mask = 0;
-
-	return info;
-}
-
-static void
-pixbuf_document_document_iface_init (EvDocumentIface *iface)
-{
-	iface->load = pixbuf_document_load;
-	iface->save = pixbuf_document_save;
-	iface->get_n_pages = pixbuf_document_get_n_pages;
-	iface->get_page_size = pixbuf_document_get_page_size;
-	iface->render = pixbuf_document_render;
-	iface->get_info = pixbuf_document_get_info;
+	ev_document_class->load = pixbuf_document_load;
+	ev_document_class->save = pixbuf_document_save;
+	ev_document_class->get_n_pages = pixbuf_document_get_n_pages;
+	ev_document_class->get_page_size = pixbuf_document_get_page_size;
+	ev_document_class->render = pixbuf_document_render;
 }
 
 static GdkPixbuf *
