@@ -15,13 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-zoom-control.h 866 2005-05-02 16:19:48Z jbowes $
+ *  $Id$
  */
 
 #ifndef EPHY_ZOOM_CONTROL_H
 #define EPHY_ZOOM_CONTROL_H
 
-#include <gtk/gtktoolitem.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
