@@ -50,24 +50,6 @@ const gchar  *ev_link_get_title  (EvLink       *self);
 EvLinkAction *ev_link_get_action (EvLink       *self);
 gint	      ev_link_get_page   (EvLink       *link);
 
-/* Link Mapping stuff */
-typedef struct _EvLinkMapping	  EvLinkMapping;
-struct _EvLinkMapping
-{
-	EvLink *link;
-	gdouble x1;
-	gdouble y1;
-	gdouble x2;
-	gdouble y2;
-};
-
-void    ev_link_mapping_free     (GList       *link_mapping);
-EvLink *ev_link_mapping_find     (GList       *link_mapping,
-				  gdouble      x,
-				  gdouble      y);
-void    ev_link_mapping_get_area (GList       *link_mapping,
-				  EvLink      *link,
-				  EvRectangle *area);
 G_END_DECLS
 
 #endif /* !EV_LINK_H */
